ekiga r6264 - in trunk: . lib/engine/protocol/skel src/endpoints
- From: dsandras svn gnome org
- To: svn-commits-list gnome org
- Subject: ekiga r6264 - in trunk: . lib/engine/protocol/skel src/endpoints
- Date: Sun, 18 May 2008 10:37:40 +0000 (UTC)
Author: dsandras
Date: Sun May 18 10:37:40 2008
New Revision: 6264
URL: http://svn.gnome.org/viewvc/ekiga?rev=6264&view=rev
Log:
Renamed ProtocolManager into CallProtocolManager to prevent
confusion with other protocol related features.
Added:
trunk/lib/engine/protocol/skel/call-protocol-manager.h
- copied, changed from r6263, /trunk/lib/engine/protocol/skel/protocol-manager.h
Removed:
trunk/lib/engine/protocol/skel/protocol-manager.h
Modified:
trunk/ChangeLog
trunk/lib/engine/protocol/skel/Makefile.am
trunk/src/endpoints/sip.h
Modified: trunk/lib/engine/protocol/skel/Makefile.am
==============================================================================
--- trunk/lib/engine/protocol/skel/Makefile.am (original)
+++ trunk/lib/engine/protocol/skel/Makefile.am Sun May 18 10:37:40 2008
@@ -13,7 +13,7 @@
$(protocol_dir)/call-manager.h \
$(protocol_dir)/call.h \
$(protocol_dir)/call-core.cpp \
- $(protocol_dir)/protocol-manager.h \
+ $(protocol_dir)/call-protocol-manager.h \
$(protocol_dir)/codec-description.h \
$(protocol_dir)/codec-description.cpp
Copied: trunk/lib/engine/protocol/skel/call-protocol-manager.h (from r6263, /trunk/lib/engine/protocol/skel/protocol-manager.h)
==============================================================================
--- trunk/src/endpoints/sip.h (original)
+++ trunk/src/endpoints/sip.h Sun May 18 10:37:40 2008
@@ -47,7 +47,7 @@
#include "manager.h"
#include "presence-core.h"
#include "call-manager.h"
-#include "protocol-manager.h"
+#include "call-protocol-manager.h"
PDICTIONARY (msgDict, PString, PString);
@@ -56,7 +56,7 @@
class GMSIPEndpoint
: public SIPEndPoint,
- public Ekiga::ProtocolManager,
+ public Ekiga::CallProtocolManager,
public Ekiga::PresenceFetcher,
public Ekiga::PresencePublisher,
public Ekiga::PresentityDecorator,
[
Date Prev][
Date Next] [
Thread Prev][
Thread Next]
[
Thread Index]
[
Date Index]
[
Author Index]
--- /trunk/lib/engine/protocol/skel/protocol-manager.h (original)
+++ trunk/lib/engine/protocol/skel/call-protocol-manager.h Sun May 18 10:37:40 2008
@@ -25,13 +25,13 @@
/*
- * protocol-manager.h - description
+ * call-protocol-manager.h - description
* ------------------------------------------
* begin : written in 2007 by Damien Sandras
* copyright : (c) 2007 by Damien Sandras
* description : Declaration of the interface of a protocol manager
* implementation backend. A call manager handles calls
* thanks to various protocol-managers.
*
*/
@@ -49,18 +49,18 @@
* @{
*/
- class ProtocolManager
+ class CallProtocolManager
{
public:
/* The constructor
*/
- ProtocolManager () {};
+ CallProtocolManager () {};
/* The destructor
*/
- ~ProtocolManager () {}
+ ~CallProtocolManager () {}
/*
Modified: trunk/src/endpoints/sip.h
==============================================================================
@@ -25,13 +25,13 @@
* begin : written in 2007 by Damien Sandras
* copyright : (c) 2007 by Damien Sandras
- * description : Declaration of the interface of a protocol manager
+ * description : Declaration of the interface of a call protocol manager
* implementation backend. A call manager handles calls
@@ -25,13 +25,13 @@
* implementation backend. A call manager handles calls
- * thanks to various protocol-managers.
+ * thanks to various call protocol managers.
*
*/